@@ -9,9 +9,9 @@ d = Dataset(psg_file)
 data = d.read_data(chan=('EEG Fpz-Cz', 'EEG Pz-Oz'), begtime=35790, endtime=35820)
 
 
-def test_detect_spindle_Moelle2002():
+def test_detect_spindle_Moelle2011():
     detsp = DetectSpindle()
-    assert repr(detsp) == 'detsp_Moelle2002_12-15Hz_00.5-03.0s'
+    assert repr(detsp) == 'detsp_Moelle2011_09-15Hz_00.5-03.0s'
 
     sp = detsp(data)
     assert len(sp.events) == 2
@@ -38,6 +38,25 @@ def test_detect_spindle_Ferrarelli2007():
     assert len(sp.events) == 0
 
 
+def test_detect_Ray2015():
+    detsp = DetectSpindle(method='Ray2015')
+    
+    sp = detsp(data)
+    assert len(sp.events) == 3
+
+
+def test_detect_spindle_FASST():
+    detsp = DetectSpindle(method='FASST')
+
+    sp = detsp(data)
+    assert len(sp.events) == 4
+
+def test_detect_spindle_FASST2():
+    detsp = DetectSpindle(method='FASST2')
+
+    sp = detsp(data)
+    assert len(sp.events) == 6
+
 def test_detect_spindle_UCSD():
     detsp = DetectSpindle(method='UCSD')
 
@@ -68,7 +87,7 @@ def test_detect_spindle_to_data():
     assert sp_data(0)[0] == 1
 
     sp_freq = sp.to_data('peak_freq')
-    assert approx(sp_freq(0)[0]) == 14.285714285714285
+    assert approx(sp_freq(0)[0]) == 13.793103448275861
 
     sp_ptp = sp.to_data('ptp')
     assert approx(sp_ptp(0)[0]) == 66.33846153846153
