@@ -9,8 +9,21 @@ from pathlib import Path
 
 from numpy import arange, asarray, empty, int64
 
-from .ioeeg import (Abf, Edf, Ktlx, BlackRock, EgiMff, FieldTrip, BrainVision,
-                    Moberg, Wonambi, Micromed, BCI2000, Text)
+from .ioeeg import (Abf,
+                    Edf,
+                    Ktlx,
+                    BlackRock,
+                    EgiMff,
+                    FieldTrip,
+                    BrainVision,
+                    Moberg,
+                    Wonambi,
+                    Micromed,
+                    BCI2000,
+                    OpenEphys,
+                    Text,
+                    BIDS,
+                    )
 from .ioeeg.bci2000 import _read_header_length
 from .datatype import ChanTime
 from .utils import UnrecognizedFormat
@@ -74,6 +87,8 @@ def detect_format(filename):
             return Moberg
         elif (filename / 'info.xml').exists():
             return EgiMff
+        elif list(filename.glob('*.openephys')):
+            return OpenEphys
         elif '.txt' in [x[-4:] for x in listdir(filename)]:
             return Text
         else:
@@ -125,6 +140,9 @@ class Dataset:
         name of the file
     IOClass : class
         one of the classes of wonambi.ioeeg
+    bids : bool
+        whether you give precedence to the information stored in the accompanying
+        files which are in the BIDS format
 
     Attributes
     ----------
@@ -159,9 +177,12 @@ class Dataset:
     differences, for example, if the argument points to a file within a
     directory, or if the file is mapped to memory.
     """
-    def __init__(self, filename, IOClass=None):
+    def __init__(self, filename, IOClass=None, bids=False):
         self.filename = Path(filename)
 
+        if bids:
+            IOClass = BIDS
+
         if IOClass is not None:
             self.IOClass = IOClass
         else:
