@@ -241,6 +241,9 @@ def create_menubar(MAIN):
     submenu_event = menu_annot.addMenu('Event')
     submenu_event.addAction(actions['new_eventtype'])
     submenu_event.addAction(actions['del_eventtype'])
+    submenu_mrk2evt = submenu_event.addMenu('Markers into events')
+    submenu_mrk2evt.addAction(actions['m2e_newname'])
+    submenu_mrk2evt.addAction(actions['m2e_keepname'])
     submenu_event.addAction(actions['merge_events'])
 
     # these are the real QActions attached to notes
@@ -262,7 +265,19 @@ def create_menubar(MAIN):
     submenu_import.addAction(actions['import_sandman'])
     submenu_import.addAction(actions['import_fasst'])
 
+    submenu_import_qual = menu_annot.addMenu('Import signal quality')
+    submenu_import_qual.addAction(actions['import_alice_qual'])
+    submenu_import_qual.addAction(actions['import_compumedics_qual'])
+    submenu_import_qual.addAction(actions['import_domino_qual'])
+    submenu_import_qual.addAction(actions['import_remlogic_qual'])
+    submenu_import_qual.addAction(actions['import_sandman_qual'])
+    menu_annot.addSeparator()
+    
     menu_annot.addAction(actions['export'])
+    
+    submenu_exp_evt = menu_annot.addMenu('Export events')
+    submenu_exp_evt.addAction(actions['exp_evt_brainvision'])
+    
     menu_annot.addSeparator()
     
     menu_annot.addAction(actions['export_sleepstats'])
