@@ -16,8 +16,9 @@ TODO:
 from datetime import datetime, timedelta
 from functools import partial
 from logging import getLogger
-from numpy import asarray, concatenate, empty, floor, nan_to_num, nanmean
+from numpy import asarray, floor
 from os.path import basename, splitext
+from pathlib import Path
 
 from PyQt5.QtCore import Qt
 from PyQt5.QtGui import QIcon, QColor
@@ -49,9 +50,11 @@ from PyQt5.QtWidgets import (QAbstractItemView,
                              QScrollArea,
                              )
 
+from .. import ChanTime
 from ..attr import Annotations, create_empty_annotations
 from ..attr.annotations import create_annotation
 from ..detect import DetectSpindle, DetectSlowWave, merge_close
+from ..ioeeg import _write_vmrk
 from .settings import Config
 from .utils import (convert_name_to_color, FormStr, FormInt, FormFloat, 
                     FormBool, FormMenu, short_strings, ICON, STAGE_NAME)
@@ -306,6 +309,14 @@ class Notes(QTabWidget):
         act.triggered.connect(self.delete_eventtype)
         actions['del_eventtype'] = act
 
+        act = QAction('New name', self)
+        act.triggered.connect(self.markers_to_events)
+        actions['m2e_newname'] = act
+        
+        act = QAction('Keep marker names', self)
+        act.triggered.connect(partial(self.markers_to_events, True))
+        actions['m2e_keepname'] = act
+        
         act = QAction('Merge Events...', self)
         act.triggered.connect(self.parent.show_merge_dialog)
         act.setEnabled(False)
@@ -384,10 +395,39 @@ class Notes(QTabWidget):
         act.triggered.connect(self.import_fasst)
         actions['import_fasst'] = act
 
+        act = QAction('Domino', self)
+        act.triggered.connect(partial(self.import_staging, 'domino', 
+                                      as_qual=True))
+        actions['import_domino_qual'] = act
+
+        act = QAction('Alice', self)
+        act.triggered.connect(partial(self.import_staging, 'alice', 
+                                      as_qual=True))
+        actions['import_alice_qual'] = act
+
+        act = QAction('Sandman', self)
+        act.triggered.connect(partial(self.import_staging, 'sandman', 
+                                      as_qual=True))
+        actions['import_sandman_qual'] = act
+
+        act = QAction('RemLogic', self)
+        act.triggered.connect(partial(self.import_staging, 'remlogic', 
+                                      as_qual=True))
+        actions['import_remlogic_qual'] = act
+
+        act = QAction('Compumedics', self)
+        act.triggered.connect(partial(self.import_staging, 'compumedics', 
+                                      as_qual=True))
+        actions['import_compumedics_qual'] = act
+
         act = QAction('Export staging', self)
         act.triggered.connect(self.export)
         actions['export'] = act
 
+        act = QAction('Brain Vision', self)
+        act.triggered.connect(partial(self.export_events, 'brainvision'))
+        actions['exp_evt_brainvision'] = act
+
         act = QAction('Spindle...', self)
         act.triggered.connect(self.parent.show_spindle_dialog)
         act.setShortcut('Ctrl+Shift+s')
@@ -400,7 +440,7 @@ class Notes(QTabWidget):
         act.setEnabled(False)
         actions['slow_wave'] = act
 
-        act = QAction('Analysis console (BETA)', self)
+        act = QAction('Analysis console', self)
         act.triggered.connect(self.parent.show_analysis_dialog)
         act.setShortcut('Ctrl+Shift+a')
         act.setEnabled(False)
@@ -605,6 +645,11 @@ class Notes(QTabWidget):
         evttype_group = QGroupBox('Event Types')
         layout = QVBoxLayout()
         evttype_group.setLayout(layout)
+        
+        self.check_all_eventtype = check_all = QCheckBox('All event types')
+        check_all.setCheckState(Qt.Checked)
+        check_all.clicked.connect(self.toggle_eventtype)
+        layout.addWidget(check_all)
 
         self.idx_eventtype_list = []
         for one_eventtype in event_types:
@@ -613,10 +658,25 @@ class Notes(QTabWidget):
             layout.addWidget(item)
             item.setCheckState(Qt.Checked)
             item.stateChanged.connect(self.update_annotations)
+            item.stateChanged.connect(self.toggle_check_all_eventtype)
             self.idx_eventtype_list.append(item)
 
         self.idx_eventtype_scroll.setWidget(evttype_group)
 
+    def toggle_eventtype(self):
+        """Check or uncheck all event types in event type scroll.""" 
+        check = self.check_all_eventtype.isChecked()
+        
+        for btn in self.idx_eventtype_list:
+            btn.setChecked(check)
+            
+    def toggle_check_all_eventtype(self):
+        """Check 'All' if all event types are checked in event type scroll."""
+        checklist = asarray([btn.isChecked for btn in self.idx_eventtype_list])
+        
+        if not checklist.all():
+            self.check_all_eventtype.setChecked(False)
+    
     def get_selected_events(self, time_selection=None):
         """Returns which events are present in one time window.
 
@@ -1012,8 +1072,8 @@ class Notes(QTabWidget):
             self.parent.statusBar().showMessage(msg)
             lg.info(msg)
 
-    def import_staging(self, source, staging_start=None, test_filename=None,
-                       test_rater=None):
+    def import_staging(self, source, staging_start=None, as_qual=False,
+                       test_filename=None, test_rater=None):
         """Action: import an external sleep staging file.
 
         Parameters
@@ -1023,6 +1083,8 @@ class Notes(QTabWidget):
             'compumedics', 'domino', 'remlogic', 'sandman'.
         staging_start : datetime, optional
             Absolute time when staging begins.
+        as_qual : bool
+            if True, scores will be imported as quality
         """
         if self.annot is None:  # remove if buttons are disabled
             msg = 'No score file loaded'
@@ -1055,7 +1117,7 @@ class Notes(QTabWidget):
             if not ok:
                 return
 
-            if rater in self.annot.raters:
+            if rater in self.annot.raters and not as_qual:
                 msgBox = QMessageBox(QMessageBox.Question, 'Overwrite staging',
                                      'Rater %s already exists. \n \n'
                                      'Overwrite %s\'s sleep staging '
@@ -1089,14 +1151,30 @@ class Notes(QTabWidget):
                 lg.info(msg)
                 return
 
+        poor = ['Artefact', 'Artifact']
+        if as_qual:
+            query = 'Which epoch label should be read as Poor quality signal?'
+            poor, ok = QInputDialog.getText(self, 'Import quality', query)
+            poor = [poor]
+            
+            if not ok:
+                return
+        
         try:
-            self.annot.import_staging(filename, source, rater,
-                                      record_start,
-                                      staging_start=staging_start)
+            unaligned = self.annot.import_staging(filename, source, rater,
+                                                  record_start,
+                                                  staging_start=staging_start,
+                                                  poor=poor, 
+                                                  as_qual=as_qual)
         except FileNotFoundError:
             msg = 'File not found'
             self.parent.statusBar().showMessage(msg)
             lg.info(msg)
+            
+        if unaligned:
+            msg = 'Imported scores are not aligned with existing scores.'
+            self.parent.statusBar().showMessage(msg)
+            lg.info(msg)
 
         self.display_notes()
         self.parent.create_menubar()  # refresh list ot raters
@@ -1159,6 +1237,8 @@ class Notes(QTabWidget):
             self.display_eventtype()
             n_eventtype = self.idx_eventtype.count()
             self.idx_eventtype.setCurrentIndex(n_eventtype - 1)
+            
+        return answer
 
     def delete_eventtype(self, test_type_str=None):
         """Action: create dialog to delete event type."""
@@ -1181,6 +1261,47 @@ class Notes(QTabWidget):
         self.annot.remove_event(name=name, time=time, chan=chan)
         self.update_annotations()
 
+    def markers_to_events(self, keep_name=False):
+        """Copy all markers in dataset to event type. """
+        markers = self.parent.info.markers
+        
+        if markers is None:
+            self.parent.statusBar.showMessage('No markers in dataset.')
+            return
+        
+        if not keep_name:
+            name, ok = self.new_eventtype()
+            
+            if not ok:
+                return
+
+        progress = QProgressDialog('Saving events', 'Abort',
+                                       0, len(markers), self)
+        progress.setWindowModality(Qt.ApplicationModal)
+        
+        for i, mrk in enumerate(markers):
+            progress.setValue(i)
+            
+            if keep_name:
+                name = mrk['name']
+                
+            self.annot.add_event(name, (mrk['start'], mrk['end']), chan='')
+            
+            if progress.wasCanceled():
+                msg = ('Conversion interrupted. Not all events were saved '
+                       'to the Annotations File.')
+                self.parent.statusBar().showMessage(msg)
+                return
+            
+        progress.setValue(i + 1)
+        
+        if keep_name:
+            self.display_eventtype()
+            n_eventtype = self.idx_eventtype.count()
+            self.idx_eventtype.setCurrentIndex(n_eventtype - 1)
+        
+        self.update_annotations()
+    
     def detect_events(self, data, method, params, label):
         """Detect events and display on signal.
 
@@ -1281,6 +1402,44 @@ class Notes(QTabWidget):
 
         self.annot.export(filename)
 
+    def export_events(self, source):
+        """Export events to external file of desired format."""
+        if self.annot is None:  # remove if buttons are disabled
+            self.parent.statusBar().showMessage('No score file loaded')
+            return
+        
+        name, ok = QInputDialog.getText(self, 'Choose Event Type',
+                                          'Enter event type to export')
+        
+        if not ok:
+            return
+        
+        if name not in self.annot.event_types:
+            self.parent.statusBar.showMessage('No such event type.')
+            return
+        
+        events = self.annot.get_events(name=name)
+        
+        if events is None:
+            self.parent.statusBar.showMessage('No events found.')
+            return
+        
+        fn, _ = QFileDialog.getSaveFileName(self, 'Export events', name)
+        
+        if fn == '':
+            return
+        
+        fn = Path(fn).resolve()
+        
+        if 'brainvision' == source:
+            dataset = self.parent.info.dataset
+            data = ChanTime()
+            data.start_time = dataset.header['start_time']
+            data.s_freq = int(dataset.header['s_freq'])
+            
+            with fn.with_suffix('.vmrk').open('w') as f:
+                f.write(_write_vmrk(data, fn, events))
+        
     def export_sleeps_stats(self):
         """action: export sleep statistics CSV."""
         if self.annot is None:  # remove if buttons are disabled
