@@ -593,14 +593,6 @@ class Traces(QGraphicsView):
                                       h_annot, zvalue=-8,
                                       color=color.lighter(120))
 
-                    """
-                    item = QGraphicsRectItem(mrk_start + 0.5, 0,
-                                             mrk_end - mrk_start - 1,
-                                             h_annot)
-                    item.setBrush(color.lighter(120))
-                    item.setPen(color.lighter(120))
-                    item.setZValue(-8)
-                    """
                     self.scene.addItem(item)
                     self.idx_annot.append(item)
 
@@ -616,17 +608,6 @@ class Traces(QGraphicsView):
                         self.scene.addItem(item)
                         self.idx_annot.append(item)
 
-                        """
-                        item = QGraphicsRectItem(mrk_start + 0.5, y,
-                                                 mrk_end - mrk_start - 1,
-                                                 y_distance)
-                        item.setBrush(color)
-                        item.setPen(color)
-                        item.setZValue(-7)
-                        self.scene.addItem(item)
-                        self.idx_annot.append(item)
-                        """
-
     def step_prev(self):
         """Go to the previous step."""
         window_start = around(self.parent.value('window_start') -
