@@ -67,6 +67,7 @@ ICON = {'application': join(icon_path, 'wonambi.jpg'),
         'event': join(oxy_path, 'edit-table-cell-merge.png'),
         'new_eventtype': join(oxy_path, 'edit-table-insert-column-right.png'),
         'del_eventtype': join(oxy_path, 'edit-table-delete-column.png'),
+        'help-about': join(oxy_path, 'help-about.png')
         }
 
 settings = QSettings("wonambi", "wonambi")
@@ -243,9 +244,9 @@ class FormRadio(QRadioButton):
 
         """
         if value:
-            self.setCheckState(Qt.Checked)
+            self.setChecked(Qt.Checked)
         else:
-            self.setCheckState(Qt.Unchecked)
+            self.setChecked(Qt.Unchecked)
 
     def connect(self, funct):
         """Call funct when user ticks the box.
